@@ -2,35 +2,27 @@
 #define _ScriptInfo_h
 
 /*
- *	subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *	Contact: kitone at free dot fr
- *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public
- *	License as published by the Free Software Foundation; either
- *	version 2 of the License, or (at your option) any later version.
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
- *	General Public License for more details.
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public
- *	License along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
- *
- *	See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *	\file
- *	\brief 
- *	\author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include <glibmm/ustring.h>
 
@@ -57,7 +49,6 @@ public:
 	Glib::ustring PlayResX;
 	Glib::ustring PlayDepth;
 	Glib::ustring Timer;	// vitesse de lecture du script en %
-	Glib::ustring Style;
 	Glib::ustring Dialogue;
 	Glib::ustring Comment;
 	Glib::ustring Picture;
