@@ -1,33 +1,25 @@
 /*
- *	subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *	Contact: kitone at free dot fr
- *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public
- *	License as published by the Free Software Foundation; either
- *	version 2 of the License, or (at your option) any later version.
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
- *	General Public License for more details.
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public
- *	License along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
- *
- *	See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *	\file
- *	\brief 
- *	\author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include "StyleModel.h"
 #include "Color.h"
@@ -51,10 +43,10 @@ Gtk::TreeIter StyleModel::append()
 	(*iter)[m_column.font_name] = "Sans";
 	(*iter)[m_column.font_size] = 18;
 
-	(*iter)[m_column.primary_colour] = blanc;
-	(*iter)[m_column.secondary_colour] = jaune;
-	(*iter)[m_column.outline_colour] = marron;
-	(*iter)[m_column.shadow_colour] = noir;
+	(*iter)[m_column.primary_colour] = blanc.to_string();
+	(*iter)[m_column.secondary_colour] = jaune.to_string();
+	(*iter)[m_column.outline_colour] = marron.to_string();
+	(*iter)[m_column.shadow_colour] = noir.to_string();
 	
 	(*iter)[m_column.bold] = false;
 	(*iter)[m_column.italic] = false;
@@ -94,10 +86,10 @@ Gtk::TreeIter StyleModel::copy( Gtk::TreeIter iter)
 	(*it)[m_column.font_name]	= (Glib::ustring)(*iter)[m_column.font_name];
 	(*it)[m_column.font_size]	= (double)(*iter)[m_column.font_size];
 
-	(*it)[m_column.primary_colour]		= (Color)(*iter)[m_column.primary_colour];
-	(*it)[m_column.secondary_colour]	= (Color)(*iter)[m_column.secondary_colour];
-	(*it)[m_column.outline_colour]		= (Color)(*iter)[m_column.outline_colour];
-	(*it)[m_column.shadow_colour]			= (Color)(*iter)[m_column.shadow_colour];
+	(*it)[m_column.primary_colour]		= (Glib::ustring)(*iter)[m_column.primary_colour];
+	(*it)[m_column.secondary_colour]	= (Glib::ustring)(*iter)[m_column.secondary_colour];
+	(*it)[m_column.outline_colour]		= (Glib::ustring)(*iter)[m_column.outline_colour];
+	(*it)[m_column.shadow_colour]			= (Glib::ustring)(*iter)[m_column.shadow_colour];
 	
 	(*it)[m_column.bold]			= (bool)(*iter)[m_column.bold];
 	(*it)[m_column.italic]		= (bool)(*iter)[m_column.italic];
@@ -144,10 +136,10 @@ void StyleModel::copy(Glib::RefPtr<StyleModel> src)
 		SET(font_name, Glib::ustring);
 		SET(font_size, double);
 
-		SET(primary_colour, Color);
-		SET(secondary_colour, Color);
-		SET(outline_colour, Color);
-		SET(shadow_colour, Color);
+		SET(primary_colour, Glib::ustring);
+		SET(secondary_colour, Glib::ustring);
+		SET(outline_colour, Glib::ustring);
+		SET(shadow_colour, Glib::ustring);
 
 		SET(bold, bool);
 		SET(italic, bool);
