@@ -2,35 +2,27 @@
 #define _SubtitleFormat_h
 
 /*
- *	subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *	Contact: kitone at free dot fr
- *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public
- *	License as published by the Free Software Foundation; either
- *	version 2 of the License, or (at your option) any later version.
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
- *	General Public License for more details.
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public
- *	License along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
- *
- *	See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *	\file
- *	\brief 
- *	\author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include <glibmm.h>
 #include "Document.h"
@@ -74,29 +66,88 @@ class SubtitleFormat
 {
 public:
 
-	SubtitleFormat(Document* doc);
-	virtual ~SubtitleFormat();
+	/*
+	 *	charset,newline sont init avec les info du doc
+	 *	il est possible de modifier les valeurs avant
+	 *	la lecture ou sauvegarde
+	 *
+	 *	ex:
+	 *	doc: charset=ISO-8859-15 & newline=Windows
+	 *	
+	 *	SubtitleFormat sf(doc);
+	 *
+	 *	sf.set_charset("UTF-8");
+	 *	sf.set_newline("Unix");
+	 *	sf.save("/home/toto/sub.srt", true);
+	 *
+	 *	doc: charset=UTF-8 & newline=Unix
+	 */
+	SubtitleFormat(Document* doc, const Glib::ustring &format_name);
 
 	/*
 	 *
 	 */
+	virtual ~SubtitleFormat();
+
+
+	/*
+	 *	"UTF-8", "ISO-8859-15" ...
+	 *	"" utilise l'auto detection
+	 */
 	void set_charset(const std::string &charset);
 
 	/*
-	 *
+	 *	"UTF-8", "ISO-8859-15" ...
+	 *	
 	 */
 	std::string get_charset();
 
+	/*
+	 *	os = "Unix" ou "Windows"
+	 */
+	void set_newline(const Glib::ustring &os);
 	
 	/*
-	 *	encoding "" pour auto ou "UTF-8", ...
+	 *	retour le '\n' ou '\r\n' selon la config du doc
+	 *	"Unix", "Windows"
 	 */
-	virtual bool open(const Glib::ustring &filename, const Glib::ustring &encoding);
+	std::string get_newline();
 	
 	/*
-	 *	encoding "" pour auto ou "UTF-8", ...
+	 *	retourne le nom du format
+	 *	ex: "SubRip", "MicroDVD"...
 	 */
-	virtual bool save(const Glib::ustring &filename, const Glib::ustring &encoding);
+	Glib::ustring get_format_name();
+
+	//virtual bool open(const Glib::ustring &filename, const Glib::ustring &encodings) { return false; }
+	//virtual bool save(const Glib::ustring &filename, const Glib::ustring &encodings) { return false; }
+
+	/*
+	 *
+	 */
+	bool open(const Glib::ustring &filename);
+	
+	/*
+	 *
+	 */
+	bool save(const Glib::ustring &filename);
+
+	/*
+	 *
+	 */
+	virtual bool on_open(const Glib::ustring &filename) = 0;
+
+	/*
+	 *
+	 */
+	virtual bool on_save(const Glib::ustring &filename) = 0;
+
+	/*
+	 *
+	 */
+	Document* document();
+
+protected:
 
 	/*
 	 *	convertir text en utf8
@@ -120,13 +171,29 @@ public:
 	 */
 	void characters_to_newline(Glib::ustring &text, const Glib::ustring &characters);
 
+
 protected:
+	/*
+	 *
+	 */
+	Glib::ustring m_format_name;
+
 	/*
 	 *	represente le charset utiliser pour la lecture (charset -> utf8) 
 	 *	ou la sauvegarde (utf8 -> charset)
 	 */
 	std::string	m_charset;
 
+	/*
+	 *
+	 */
+	std::string	m_newline;
+
+	/*
+	 *
+	 */
+	Document* m_document;
+
 	/*
 	 *
 	 */
@@ -137,15 +204,11 @@ protected:
 	 */
 	ScriptInfo*	m_scriptInfo;
 
-	/*
-	 *
-	 */
-	Glib::RefPtr<SubtitleModel> m_subtitleModel;
-
 	/*
 	 *
 	 */
 	Glib::RefPtr<StyleModel> m_styleModel;
+
 private:
 	std::list<Glib::ustring> m_list_encodings;
 	bool	m_use_auto_deteced;
