@@ -2,40 +2,36 @@
 #define _SubtitleView_h
 
 /*
- *  subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *  Contact: kitone at free dot fr
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *	This program is distributed in the hope that it will be useful,
+ *	but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public
- *  License along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *  \file
- *  \brief 
- *  \author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include <gtkmm/treeview.h>
 #include <libglademm.h>
-#include "SubtitleModel.h"
-#include "Document.h"
+//#include "SubtitleModel.h"
+#include "StyleModel.h"
+#include "Config.h"
+
+class Document;
+class SubtitleModel;
 
 /*
  *
@@ -43,15 +39,28 @@
 class SubtitleView : public Gtk::TreeView
 {
 public:
-  SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	SubtitleView(Document &doc);
 	~SubtitleView();
-	
-	void loadCfg();
-	void saveCfg();
 
   /*
-   *  create columns
+   *	return first iter select
    */
+  Gtk::TreeIter   getSelected();
+
+	/*
+	 *	select and set the cursor on iter
+	 */
+  void select_and_set_cursor(const Gtk::TreeIter &iter);
+
+protected:	
+	void loadCfg();
+
+  /*
+   *  create columns with the config order
+	 *  ["subtitle-view"] columns="number;layer;..."
+   */
+	void createColumns();
+
   void createColumnNum();
 	void createColumnLayer();
   void createColumnStart();
@@ -64,14 +73,15 @@ public:
   void createColumnMarginV();
 	void createColumnEffect();
   void createColumnText();
+  void createColumnCPS();
 	void createColumnTranslation();
-	void createColumnCharactersPerLine();
+	void createColumnNote();
  
-  
-  /*
-   *
-   */
-  Gtk::TreeIter   getSelected();
+	/*
+	 *	
+	 */
+	void update_columns_order();
+
 
 	/*
 	 *
@@ -105,7 +115,9 @@ public:
   void on_edited_text(const Glib::ustring &path, const Glib::ustring &newtext);
 
   void on_edited_translation(const Glib::ustring &path, const Glib::ustring &newtext);
-  void on_edited_effect(const Glib::ustring &path, const Glib::ustring &newtext);
+  void on_edited_note(const Glib::ustring &path, const Glib::ustring &newtext);
+
+	void on_edited_effect(const Glib::ustring &path, const Glib::ustring &newtext);
 
 	/*
 	 *	callback utiliser pour modifier le style (a partir d'un menu, cell renderer combo)
@@ -127,18 +139,30 @@ public:
 	/*
 	 *
 	 */
-  void select_and_set_cursor(const Gtk::TreeIter &iter);
+	void on_set_style_to_selection(const Glib::ustring &name);
 
 
 	/*
-	 *	passe d'une vue simple pour le format SRT 
-	 *	a la vue total (SSA)
-	 *	afficher certaine colonne ou non
-	 *	"srt" ou "ssa"
+	 *
 	 */
-	void set_view_type(const Glib::ustring &type);
+	void on_execute_action(const Glib::ustring &action);
 	
 
+
+	/*
+	 *	COLUMN
+	 */
+
+	/*
+	 *	retourne le nom utiliser en interne de la column
+	 */
+	Glib::ustring get_name_of_column(Gtk::TreeViewColumn *column);
+	
+	/*
+	 *	retourne la colonne par rapport a son nom (interne)
+	 */
+	Gtk::TreeViewColumn* get_column_by_name(const Glib::ustring &name);
+	
 	/*
 	 *
 	 */
@@ -149,19 +173,48 @@ public:
 	 */
 	bool get_column_visible(const Glib::ustring &name);
 
+	
+	
 	/*
 	 *
 	 */
-	//bool on_key_press_event(GdkEventKey *event);
-	//void editing_start(Gtk::CellEditable* cell, const Glib::ustring &path);
-	//bool entry_key_press_event(GdkEventKey *ev);
-protected:
+	bool on_key_press_event(GdkEventKey *event);
+
+	/*
+	 *
+	 */
+	bool on_button_press_event(GdkEventButton *ev);
+	
+	
+	/*
+	 *	il y a eu des changements dans la configuration du groupe "subtitle-view"
+	 */
+	void on_config_subtitle_view_changed(const Glib::ustring &key, const Glib::ustring &value);
 
 	/*
 	 *
 	 */
 	void set_tooltips(Gtk::TreeViewColumn *column, const Glib::ustring &text);
 
+	/*
+	 *	CLIPBOARD
+	 */
+
+	/*
+	 *
+	 */
+	void clipboard_cut();
+
+	/*
+	 *
+	 */
+	void clipboard_copy();
+	
+	/*
+	 *
+	 */
+	void clipboard_paste();
+
 protected:
 	Document*			m_refDocument;
 	
@@ -172,6 +225,8 @@ protected:
 
 	// pointe sur les columns par rapport a leur nom
 	std::map<Glib::ustring, Gtk::TreeViewColumn*>	m_columns;
+
+	Gtk::Menu m_menu_popup;
 };
 
 
